Constraints

Struct Constraints 

pub struct Constraints {
    pub min_width: f32,
    pub max_width: f32,
    pub min_height: f32,
    pub max_height: f32,
}
Layout constraints that specify minimum and maximum sizes.

Examples

use presentar_core::{Constraints, Size};

// Tight constraints allow only one size
let tight = Constraints::tight(Size::new(100.0, 50.0));
assert_eq!(tight.min_width, 100.0);
assert_eq!(tight.max_width, 100.0);

// Loose constraints allow any size up to maximum
let loose = Constraints::loose(Size::new(400.0, 300.0));
assert_eq!(loose.min_width, 0.0);
assert_eq!(loose.max_width, 400.0);

Fields

min_width: f32

Minimum width

max_width: f32

Maximum width

min_height: f32

Minimum height

max_height: f32

Maximum height

Implementations

Source

impl Constraints

pub const fn new( min_width: f32, max_width: f32, min_height: f32, max_height: f32, ) -> Constraints

Create new constraints.

pub const fn tight(size: Size) -> Constraints

Create tight constraints that allow only the exact size.

pub const fn loose(size: Size) -> Constraints

Create loose constraints that allow any size up to the given maximum.

pub const fn unbounded() -> Constraints

Create unbounded constraints.

pub fn constrain(&self, size: Size) -> Size

Constrain a size to fit within these constraints.

pub fn is_tight(&self) -> bool

Check if constraints specify an exact size.

pub fn has_bounded_width(&self) -> bool

Check if width is bounded (not infinite).

pub fn has_bounded_height(&self) -> bool

Check if height is bounded (not infinite).

pub fn is_bounded(&self) -> bool

Check if both dimensions are bounded.

pub fn biggest(&self) -> Size

Get the biggest size that satisfies these constraints.

pub const fn smallest(&self) -> Size

Get the smallest size that satisfies these constraints.

pub const fn with_min_width(&self, min_width: f32) -> Constraints

Create constraints with a different minimum width.

pub const fn with_max_width(&self, max_width: f32) -> Constraints

Create constraints with a different maximum width.

pub const fn with_min_height(&self, min_height: f32) -> Constraints

Create constraints with a different minimum height.

pub const fn with_max_height(&self, max_height: f32) -> Constraints

Create constraints with a different maximum height.

pub fn deflate(&self, horizontal: f32, vertical: f32) -> Constraints

Deflate constraints by padding.