pub struct DiffRenderer { /* private fields */ }Expand description
Differential renderer that minimizes terminal I/O.
Tracks the current cursor position and style state to avoid redundant escape sequences.
Implementations
Sourceimpl DiffRenderer
impl DiffRenderer
Sourcepub fn new() -> DiffRenderer
pub fn new() -> DiffRenderer
Create a new renderer.
Sourcepub fn with_color_mode(color_mode: ColorMode) -> DiffRenderer
pub fn with_color_mode(color_mode: ColorMode) -> DiffRenderer
Create a renderer with specific color mode.
Sourcepub fn set_color_mode(&mut self, mode: ColorMode)
pub fn set_color_mode(&mut self, mode: ColorMode)
Set the color mode.
Sourcepub const fn color_mode(&self) -> ColorMode
pub const fn color_mode(&self) -> ColorMode
Get the color mode.
Sourcepub const fn cells_written(&self) -> usize
pub const fn cells_written(&self) -> usize
Get cells written in last flush.
Sourcepub const fn cursor_moves(&self) -> usize
pub const fn cursor_moves(&self) -> usize
Get cursor moves in last flush.
Sourcepub const fn style_changes(&self) -> usize
pub const fn style_changes(&self) -> usize
Get style changes in last flush.
Sourcepub fn flush<W>(
&mut self,
buffer: &mut CellBuffer,
writer: &mut W,
) -> Result<usize, Error>where
W: Write,
pub fn flush<W>(
&mut self,
buffer: &mut CellBuffer,
writer: &mut W,
) -> Result<usize, Error>where
W: Write,
Flush dirty cells to the writer.
Returns the number of cells written.
Errors
Returns an error if writing to the writer fails.
Sourcepub fn render_full<W>(
&mut self,
buffer: &mut CellBuffer,
writer: &mut W,
) -> Result<usize, Error>where
W: Write,
pub fn render_full<W>(
&mut self,
buffer: &mut CellBuffer,
writer: &mut W,
) -> Result<usize, Error>where
W: Write,