pub struct Rect {
pub x: f32,
pub y: f32,
pub width: f32,
pub height: f32,
}Expand description
A rectangle defined by position and size.
Fields
x: f32X position of top-left corner
y: f32Y position of top-left corner
width: f32Width
height: f32Height
Implementations
Sourceimpl Rect
impl Rect
Sourcepub fn from_points(top_left: Point, bottom_right: Point) -> Rect
pub fn from_points(top_left: Point, bottom_right: Point) -> Rect
Create from two corner points.
Sourcepub fn bottom_left(&self) -> Point
pub fn bottom_left(&self) -> Point
Get bottom-left corner.
Sourcepub fn bottom_right(&self) -> Point
pub fn bottom_right(&self) -> Point
Get bottom-right corner.
Sourcepub fn contains_point(&self, point: &Point) -> bool
pub fn contains_point(&self, point: &Point) -> bool
Check if a point is inside the rectangle (inclusive).
Sourcepub fn intersects(&self, other: &Rect) -> bool
pub fn intersects(&self, other: &Rect) -> bool
Check if this rectangle intersects another.
Sourcepub fn intersection(&self, other: &Rect) -> Option<Rect>
pub fn intersection(&self, other: &Rect) -> Option<Rect>
Calculate intersection with another rectangle.
Sourcepub fn inset(&self, amount: f32) -> Rect
pub fn inset(&self, amount: f32) -> Rect
Create a new rectangle inset by the given amount on all sides.
Sourcepub const fn with_origin(&self, origin: Point) -> Rect
pub const fn with_origin(&self, origin: Point) -> Rect
Create a new rectangle with the given position.