pub enum ColorMode {
TrueColor,
Color256,
Color16,
Mono,
}Expand description
Terminal color capability mode.
Variants
TrueColor
24-bit true color (COLORTERM=truecolor or 24bit).
Color256
256 color palette.
Color16
16 ANSI colors.
Mono
Monochrome (no color).
Implementations
Sourceimpl ColorMode
impl ColorMode
Sourcepub fn detect_with_env(
colorterm: Option<String>,
term: Option<String>,
) -> ColorMode
pub fn detect_with_env( colorterm: Option<String>, term: Option<String>, ) -> ColorMode
Detect color mode from environment variable values.
This is the testable core of detect().
Sourcepub fn to_crossterm(&self, color: Color) -> Color
pub fn to_crossterm(&self, color: Color) -> Color
Convert a presentar Color to crossterm Color based on this mode.
Note: Transparent colors (alpha = 0) return CrosstermColor::Reset which
uses the terminal’s default background color instead of rendering as black.